@@ -1,5 +1,5 @@
 import datetime
-from typing import Any, Callable, Dict, Optional, Union, cast
+from typing import Any, Callable, Dict, List, Optional, Union, cast
 
 import attr
 from dateutil.parser import isoparse
@@ -23,6 +23,7 @@ class Reservation:
     cancelled: Union[Unset, bool] = UNSET
     notes: Union[Unset, str] = UNSET
     updated_time: Union[Unset, datetime.datetime] = UNSET
+    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self, pick_by_predicate: Optional[Callable[[Any], bool]] = is_not_none) -> Dict[str, Any]:
         assert self.created_time.tzinfo is not None, "Datetime must have timezone information"
@@ -45,9 +46,10 @@ class Reservation:
             assert self.updated_time.tzinfo is not None, "Datetime must have timezone information"
             updated_time = rfc3339(self.updated_time)
 
-        dct = {
-            k: v
-            for k, v in {
+        field_dict: Dict[str, Any] = {}
+        field_dict.update(self.additional_properties)
+        field_dict.update(
+            {
                 "createdTime": created_time,
                 "endTime": end_time,
                 "id": id,
@@ -55,41 +57,47 @@ class Reservation:
                 "quantumProcessorId": quantum_processor_id,
                 "startTime": start_time,
                 "userId": user_id,
-                "cancelled": cancelled,
-                "notes": notes,
-                "updatedTime": updated_time,
-            }.items()
-            if v != UNSET
-        }
+            }
+        )
+        if cancelled is not UNSET:
+            field_dict["cancelled"] = cancelled
+        if notes is not UNSET:
+            field_dict["notes"] = notes
+        if updated_time is not UNSET:
+            field_dict["updatedTime"] = updated_time
+
+        field_dict = {k: v for k, v in field_dict.items() if v != UNSET}
         if pick_by_predicate is not None:
-            dct = {k: v for k, v in dct.items() if pick_by_predicate(v)}
-        return dct
+            field_dict = {k: v for k, v in field_dict.items() if pick_by_predicate(v)}
+
+        return field_dict
 
     @staticmethod
-    def from_dict(d: Dict[str, Any]) -> "Reservation":
-        created_time = isoparse(d["createdTime"])
+    def from_dict(src_dict: Dict[str, Any]) -> "Reservation":
+        d = src_dict.copy()
+        created_time = isoparse(d.pop("createdTime"))
 
-        end_time = isoparse(d["endTime"])
+        end_time = isoparse(d.pop("endTime"))
 
-        id = d["id"]
+        id = d.pop("id")
 
-        price = d["price"]
+        price = d.pop("price")
 
-        quantum_processor_id = d["quantumProcessorId"]
+        quantum_processor_id = d.pop("quantumProcessorId")
 
-        start_time = isoparse(d["startTime"])
+        start_time = isoparse(d.pop("startTime"))
 
-        user_id = d["userId"]
+        user_id = d.pop("userId")
 
-        cancelled = d.get("cancelled")
+        cancelled = d.pop("cancelled", UNSET)
 
-        notes = d.get("notes")
+        notes = d.pop("notes", UNSET)
 
         updated_time = None
-        if d.get("updatedTime") is not None:
-            updated_time = isoparse(cast(str, d.get("updatedTime")))
+        if d.pop("updatedTime", UNSET) is not None:
+            updated_time = isoparse(cast(str, d.pop("updatedTime", UNSET)))
 
-        return Reservation(
+        reservation = Reservation(
             created_time=created_time,
             end_time=end_time,
             id=id,
@@ -101,3 +109,22 @@ class Reservation:
             notes=notes,
             updated_time=updated_time,
         )
+
+        reservation.additional_properties = d
+        return reservation
+
+    @property
+    def additional_keys(self) -> List[str]:
+        return list(self.additional_properties.keys())
+
+    def __getitem__(self, key: str) -> Any:
+        return self.additional_properties[key]
+
+    def __setitem__(self, key: str, value: Any) -> None:
+        self.additional_properties[key] = value
+
+    def __delitem__(self, key: str) -> None:
+        del self.additional_properties[key]
+
+    def __contains__(self, key: str) -> bool:
+        return key in self.additional_properties
